==> haskell-x509-store-1.6.2-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
key: x509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: c238ca96488a40f17e6d3e71856dd644
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
depends:
    asn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
    asn1-types-0.3.2-KYu7pQLyIazKugAPAWEtdg base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-BghVPg0sVunAfXbG7gt71d directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-Da2tKOhQUlTA2oOdKTHYT4
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.2-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-BXSkkYlpuOMCVOYYZxnB5x
key: x509-store-1.6.2-BXSkkYlpuOMCVOYYZxnB5x
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: a79fd942c16ad5452a44d91270b37ef5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-BXSkkYlpuOMCVOYYZxnB5x
depends:
    asn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
    asn1-types-0.3.2-KYu7pQLyIazKugAPAWEtdg base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.23-IZJ66Y8jjDgmndLH4VfVr directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-DTcGavhdY587qh4PDuwE2S
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
